function [ h, x, y ] = plotmodels( models, x, modelvar, plotfunc )
% grj 16/5/2013
%
% models = a
%
%plots the independent variable, x, against the models struct component,
%modelVar.
%
%plotfunc is an optional function handle for plotting the parameters
%
%the model parameter value gets concatonated along the first non-singleton
%dimension
%
%returns plot handle, x, and y values

if ~exist('x', 'var')
    x = ones(1, length(models));
end

if iscell(models)
    models = [models{:}];
end

tokens = regexp(modelvar, '\.', 'split');

%Get the data from each model
for i = 1:length(models)
    model = models(i);
    for j = 1:length(tokens)
        model = model.(tokens{j});
    end
   
    y{i} = model;
end

%Concationate data by the first singleton dimension
ysize = size(y{1});

inds = find(ysize ==1);

if isempty(inds)
    inds = length(ysize) +1;
end

y = cat(inds(1), y{:});
        
if exist('plotfunc', 'var') & ~isempty(plotfunc)
    h = plotfunc(x, y);
else
    h = scatter(x,y);
end

end
